@@ -1,5 +1,6 @@
 """Test the pypdf._reader module."""
 import io
+import sys
 import time
 from io import BytesIO
 from pathlib import Path
@@ -17,6 +18,7 @@ from pypdf.errors import (
     DeprecationError,
     EmptyFileError,
     FileNotDecryptedError,
+    LimitReachedError,
     PdfReadError,
     PdfStreamError,
     WrongPasswordError,
@@ -418,7 +420,7 @@ def test_get_page_of_encrypted_file(pdffile, password, should_fail):
             "crazyones.pdf",
             {},
             None,
-        ),
+        )
     ],
 )
 def test_get_form(src, expected, expected_get_fields, txt_file_path):
@@ -448,6 +450,21 @@ def test_get_form(src, expected, expected_get_fields, txt_file_path):
             ]
 
 
+@pytest.mark.enable_socket
+def test_reading_choice_field_without_opt_key():
+    """Tests reading a choice field in a PDF without an /Opt key."""
+    url = "https://github.com/user-attachments/files/23853677/Musterservicevertrag-HNRAGB_Okt2022-Blanko.pdf"
+    reader = PdfReader(BytesIO(get_data_from_url(url, name="Musterservicevertrag-HNRAGB_Okt2022-Blanko.pdf")))
+    fields = reader.get_fields()
+
+    tn_anrede = fields.get("TN_Anrede")
+    assert tn_anrede is not None
+
+    # Ensure that parsing of a choice field without /Opt key worked
+    tn_anrede_opt = tn_anrede.get("/Opt")
+    assert tn_anrede_opt is None
+
+
 @pytest.mark.parametrize(
     ("src", "page_number"),
     [
@@ -1863,3 +1880,101 @@ def test_read_pdf15_xref_stream():
             match=r"^Trailer cannot be read: Limit reached while decompressing\. 1545392 bytes remaining\.$"
     ):
         PdfReader(BytesIO(data_modified))
+
+
+@pytest.mark.enable_socket
+def test_read_standard_xref_table__two_whitespace_characters_between_offset_and_generation():
+    """Tests for #3482"""
+    url = "https://github.com/user-attachments/files/22591813/helloworld.pdf"
+    name = "issue3482.pdf"
+
+    reader = PdfReader(BytesIO(get_data_from_url(url, name=name)))
+    assert len(reader.pages) == 1
+    assert reader.pages[0].extract_text() == "Hello World!"
+
+
+@pytest.mark.enable_socket
+def test_root_object_recovery_limit(caplog):
+    url = "https://github.com/user-attachments/files/24525509/root_object_recovery_limit.pdf"
+    name = "root_object_recovery_limit.pdf"
+    data = get_data_from_url(url, name=name)
+
+    # Default limit.
+    reader = PdfReader(BytesIO(data))
+    with pytest.raises(
+            expected_exception=LimitReachedError, match=r"^Maximum Root object recovery limit reached\.$"
+    ):
+        _ = list(reader.pages)
+    message_numbers = {
+        int(message.split(" ", maxsplit=2)[1])
+        for message in caplog.messages
+        if message.startswith("Object ") and message.endswith(" 0 not defined.")
+    }
+    assert sorted(message_numbers) == list(range(5, 10001))
+
+    # Custom limit.
+    caplog.clear()
+    reader = PdfReader(BytesIO(data), root_object_recovery_limit=42)
+    with pytest.raises(
+            expected_exception=LimitReachedError, match=r"^Maximum Root object recovery limit reached\.$"
+    ):
+        _ = list(reader.pages)
+    message_numbers = {
+        int(message.split(" ", maxsplit=2)[1])
+        for message in caplog.messages
+        if message.startswith("Object ") and message.endswith(" 0 not defined.")
+    }
+    assert sorted(message_numbers) == list(range(5, 43))
+
+    # No limit. Do not run actual process for speed reasons.
+    reader = PdfReader(BytesIO(data), root_object_recovery_limit=None)
+    assert reader._root_object_recovery_limit == sys.maxsize
+
+    # Strict mode.
+    with pytest.raises(expected_exception=PdfReadError, match=r"^Broken xref table$"):
+        reader = PdfReader(BytesIO(data), strict=True)
+        _ = list(reader.pages)
+
+
+@pytest.mark.timeout(10)
+def test_rebuild_xref_table__speed():
+    total_len = 2_000_790
+    middle = b"\nstartxref   1\n % "
+    leading_len = 0x55E  # 1374
+    leading = b" " * leading_len
+    trailing = b" " * (total_len - leading_len - len(middle))
+    data = leading + middle + trailing
+
+    reader = PdfReader(BytesIO(data))
+    with pytest.raises(expected_exception=PdfReadError, match=r"^Cannot find Root object in pdf$"):
+        _ = list(reader.pages)
+
+
+def test_find_pdf_objects():
+    data = (
+        b"     \n"
+        b"  11 0 obj\n"
+        b"  12 0 obj\n"
+        b"13  1  obj\n"
+        b"ob\n"
+        b"ab obj\n"
+        b"42 1337 obj \n"
+        b"\n"
+    )
+
+    result = list(PdfReader._find_pdf_objects(data))
+    assert result == [(11, 0, 8), (12, 0, 19), (13, 1, 28), (42, 1337, 49)]
+
+
+@pytest.mark.parametrize(
+    ("data", "expected"),
+    [
+        (b"\n\ntrailer", []),
+        (b"\n\ntrailer abc", []),
+        (b"\n\ntrailer <<", [10]),
+        (b"\n\ntrailer << /Key null >>\n\n  trailer << /Key 42 >>\n", [10, 37])
+    ]
+)
+def test_find_pdf_trailers(data: bytes, expected: list[int]):
+    result = list(PdfReader._find_pdf_trailers(data))
+    assert result == expected
